#
# spec file for package mate-media
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _version 1.20
Name:           mate-media
Version:        1.20.0
Release:        lp150.1.1
Summary:        MATE Desktop multimedia stack
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/Other
Url:            https://mate-desktop.org/
Source:         http://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
# PATCH-FEATURE-OPENSUSE mate-media-gtk-3.20.patch -- Restore GLib 2.48 and GTK+ 3.20 support.
Patch0:         mate-media-gtk-3.20.patch
BuildRequires:  fdupes
BuildRequires:  itstool
BuildRequires:  mate-common >= %{_version}
BuildRequires:  mate-control-center-devel >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(glib-2.0) >= 2.48
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libmatemixer) >= %{_version}
BuildRequires:  pkgconfig(libxml-2.0)
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
This package provides the Multimedia stack used by the MATE Desktop.

%lang_package

%prep
%setup -q
%patch0 -p1

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --disable-static                    \
  --libexecdir=%{_libexecdir}/%{name} \
  --enable-profiles
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file mate-volume-control
%fdupes %{buildroot}%{_datadir}/

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%glib2_gsettings_schema_post

%postun
%desktop_database_postun
%glib2_gsettings_schema_postun
%endif

%files
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif
%doc AUTHORS NEWS README
%{_sysconfdir}/xdg/autostart/mate-volume-control-applet.desktop
%{_bindir}/mate-volume-control
%{_bindir}/mate-volume-control-applet
%{_datadir}/applications/*.desktop
%{_datadir}/mate-media/
%{_datadir}/sounds/mate/
%{_mandir}/man?/mate-volume-control-applet.?%{?ext_man}
%{_mandir}/man?/mate-volume-control.?%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * volume-control-dialog: Avoid deprecated GtkAlignment.
  * applet: Improve volume increments.
  * Avoid deprecated gdk_screen_get_monitor_,
    gdk_screen_get_height() functions.
  * applet: Use GdkSeat.
  * gvc-applet: Don't try to increase refcount of a NULL object.
  * gvc-combo-box: Fix signal arguments.
- Add mate-media-gtk-3.20.patch: Restore GLib 2.48 and GTK+ 3.20
  support.
* Tue Nov  7 2017 sor.alexei@meowr.ru
- Update to version 1.18.2:
  * applet: Restore the icon for the "Sound Preferences" menu item.
  * applet: Make keyboard work in pop ups.
  * Refresh the tray icon on icon theme change.
  * Update translations.
* Sat Jun 17 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * mixer-dialogue: Remove style class .frame from a
    scrolledwindow.
  * applet: Show volume in popup even when muted.
  * applet: Round volume in popup of status icon.
  * applet: Fix minor rounding mistakes.
  * Enable deprecation warnings by default.
  * Restore Polish translation credits from GNOME.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Build: Require libmatemixer >= 1.10 and libmate-desktop >= 1.17.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * Port from libunique to GApplication and GtkApplication.
  * Some cleanups.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Update translations.
* Sun Aug 14 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * GTK+3: Add CSS name gvc-level-bar.
  * Make distcheck use currently selected GTK+ version.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * GTK+3: add css name GvcMixerDialog for Gtk 3.20.
  * Update translations.
  * Fix Changelog generation.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * GTK+3: Fix several deprecations.
* Mon Nov 30 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Gtk3: Don't remove slider background (fixes background in some
    themes).
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
* Wed Oct 14 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Multiple fixes in manpages.
  * GTK+3: Fix missing icons with custom icon theme.
  * GTK+3: Add style classes for slider and menu for volume-applet.
  * Update translations.
* Mon May  4 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * No changes since version 1.9.2
* Sun Nov 23 2014 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  + Do not create the volume slider when not supported by the
    libmatemixer backend
  + Remove the add_effects_control function as it does the same as
    bar_set_stream_control
  + Move the widget construction code from constructor to its own
    function
  + Remove some extraneous variables and improve debugging messages
  + Bugs fixed
* Tue Nov 11 2014 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + Removed PulseAudio dependency
- Remove pkgconfig(libpulse) and "--enable-pulse" configue option;
  pulseaudio dependency has been dropped by upstream
- Add libmatemixer-devel build requirement; new dependency
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + Removed gst-mixer and gst-mixer-applet
  + mate-volume-control: Port from PulseAudio to libmatemixer
  + mate-volume-control: Allow selecting input and output connectors
  + mate-volume-control: Speaker test widget now contains a Close button
  + mate-volume-control: Device and stream lists are now sorted
  + mate-volume-control-applet: Do not show icons when on a vertical panel
  + mate-volume-control-applet: Allow clicking in the popup window
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
- Remove useless require; never been dependencies
  + gladeui-1.0
  + glib-2.0
  + gobject-2.0
- Remove gstreamer-* require as we don't build with gstreamer support
* Thu Feb 20 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + no changes since 1.7.1
* Fri Feb 14 2014 p.drouand@gmail.com
- Update to version 1.7.1 (unstable)
  + pulse: Middle click on applet toggles mute state
    Closes #20 (https://github.com/mate-desktop/mate-media/issues/20)
  + update translations
* Wed Jan 22 2014 p.drouand@gmail.com
- Update to version 1.7.0
  + use yelp-tools instead of mate-doc-utils
  + mate-volume-control: Allow applications list to be scrolled
    Closes #31 (https://github.com/mate-desktop/mate-media/issues/31)
  + add/update files in POTFILES.in and fix make check
  + add GTK3 support
  + just use MATE_COMPILE_WARNINGS(maximum) and remove custom macros
  + make tar.xz instead of tar.bz2
  + add option to enable deprecated
  + enable deprecated in DISTCHECK_CONFIGURE_FLAGS
    The problem is that without the Gstatic*Mutex the gstreamer mixer
    fails to build. This is because Gstatic*Mutex is deprecated in glib
    but still in use by gstreamer 0.10. To have make distcheck work we
    enable it here.
  + add --enable-deprecated and put it in DISTCHECK_CONFIGURE_FLAGS
  + fix Sun GNOME Documentation Team references
  + disable all deprecated flags
- Replace mate-doc-utils requirement with yelp-utils; upstream use
  this one to build help documentation
* Wed Jan  1 2014 p.drouand@gmail.com
- Update to version 1.6.1
  + Add/update files in POTFILES.in and fix make check
  + Remove autogenerated files
  + Remove unused m4 files
  + just use MATE_COMPILE_WARNINGS(maximum) and remove custom macros
  + Generate ChangeLog from git log
  + Make tar.xz instead of tar.bz2
  + Add option to enable deprecated
  + Enable deprecated in DISTCHECK_CONFIGURE_FLAGS
    The problem is that without the Gstatic*Mutex the gstreamer mixer
    fails to build. This is because Gstatic*Mutex is deprecated in glib
    but still in use by gstreamer 0.10To have make distcheck work we
    enable it here.
  + gstreamer: Middle click on applet toggles mute state
  + display gst-mixer and mate-volume-control also in multimadia menu
  + Fix Sun GNOME Documentation Team references
* Thu Sep 19 2013 p.drouand@gmail.com
- Remove old Provides/Obsoletes entries as we don't need it here
- Unversion lang package requirement
* Thu Apr  4 2013 p.drouand@gmail.com
- Update to version 1.6.0
  + Add Recommends:     %%{name}-lang = %%{version}-%%{release}
  + fix OnlyShowIn in mate-volume-control-applet.desktop
* Sat Mar 23 2013 p.drouand@gmail.com
- Update to version 1.5.2
  + fix typo in configure.ac
  + fix mixer applet build in configure and makefile
  + fix FSF adress in COPYING file
  + fix categories in desktop files
  + fix gst-mixer compilation errors the right way
  + remove ^L's from COPYING.gst-mixer
  + fix deprecations
  + AC_CONFIG_HEADERS to please automake 1.13
  + update mate-volume-control.desktop.in.in
  - choose a unique name
  - add generic name
- Remove obsolete patchs; merged on upstream release
  + mate-media-1.5.1-fix_categories.patch
  + mate-media-1.5.1-update_COPYING.patch
* Thu Mar 14 2013 nmo.marques@gmail.com
- Add 'pulseaudio-utils' to Reqs; otherwise if pulseaudio isnt
  properly installed, no applet on menu.
* Thu Feb 28 2013 hillwood@linuxfans.org
- Drop GStreamer mixer support.
* Sun Dec  9 2012 nmo.marques@gmail.com
- Update to verison 1.5.1
  + fix mixer applet build in configure and makefile
  + fix typo in configure.ac
  + add gst-mixer-applet (moved from mate-applets package)
  + fix FSF addresses
- Split GStreamer mixer applet from main package and add
  libmatepanelapplet-4.0 to BRs
- Drop previous patches (1.5.0)
- Add mate-media-1.5.1-fix_categories.patch: fix desktop file
  categories, upstreamed
- Add mate-media-1.5.1-update_COPYING.patch: update COPYING,
  upstreamed
* Thu Nov  8 2012 nmo.marques@gmail.com
- Update to version 1.5.0
  + migration from mateconf-2.0 to gsettings
- Add dbus-1 to BRs
- Supress devel and glade3 packages; no longer provides, leaving
  obsolets/provides behind to remove stuff from users
* Sun Sep  9 2012 nmo.marques@gmail.com
- Spec file cleanups and rpmlint warnings/errors fixing
* Tue Aug 28 2012 hillwood@linuxfans.org
- initial package from version 1.4.0
